==> onos-yang-runtime-2.2.0-b5-sources.jar: org/onosproject/yang/gen/v1/yrtsubscription/yrtsubscription/test/value/DefaultAugmentedValue.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.test.value;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.test.value.augmentedvalue.Proceed;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augmentedValue.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugmentedValue extends InnerModelObject implements AugmentedValue {
    protected Proceed proceed;

    @Override
    public Proceed proceed() {
        return proceed;
    }

    @Override
    public void proceed(Proceed proceed) {
        this.proceed = proceed;
    }

    @Override
    public int hashCode() {
        return Objects.hash(proceed);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugmentedValue) {
            DefaultAugmentedValue other = (DefaultAugmentedValue) obj;
            return
                Objects.equals(proceed, other.proceed);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("proceed=" + proceed)
            .toString();
    }


    /**
     * Creates an instance of defaultAugmentedValue.
     */
    public DefaultAugmentedValue() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtsubscription/yrtsubscription/test/value/DefaultAugmentedValue.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.test.value;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.test.value.augmentedvalue.Proceed;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augmentedValue.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugmentedValue extends InnerModelObject implements AugmentedValue {
    protected Proceed proceed;

    @Override
    public Proceed proceed() {
        return proceed;
    }

    @Override
    public void proceed(Proceed proceed) {
        this.proceed = proceed;
    }

    @Override
    public int hashCode() {
        return Objects.hash(proceed);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugmentedValue) {
            DefaultAugmentedValue other = (DefaultAugmentedValue) obj;
            return
                Objects.deepEquals(proceed, other.proceed);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("proceed=" + proceed)
            .toString();
    }


    /**
     * Creates an instance of defaultAugmentedValue.
     */
    public DefaultAugmentedValue() {
    }

}
